package com.ruoyi.system.mapper.colums;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.system.domain.columns.SysTeacher;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 员工信息Mapper接口
 *
 * @author ruoyi
 * @date 2025-10-28
 */
public interface SysTeacherMapper
{
    /**
     * 查询员工信息
     *
     * @param userId 员工信息主键
     * @return 员工信息
     */
    public SysTeacher selectSysTeacherByUserId(Long userId);

    /**
     * 查询员工信息列表
     *
     * @param sysTeacher 员工信息
     * @return 员工信息集合
     */
    public List<SysTeacher> selectSysTeacherList(SysTeacher sysTeacher);
    public List<SysUser> getUserForTeacher(SysTeacher sysTeacher);

    /**
     * 新增员工信息
     *
     * @param sysTeacher 员工信息
     * @return 结果
     */
    public int insertSysTeacher(SysTeacher sysTeacher);

    /**
     * 修改员工信息
     *
     * @param sysTeacher 员工信息
     * @return 结果
     */
    public int updateSysTeacher(SysTeacher sysTeacher);

    /**
     * 删除员工信息
     *
     * @param userId 员工信息主键
     * @return 结果
     */
    public int deleteSysTeacherByUserId(Long userId);

    /**
     * 批量删除员工信息
     *
     * @param userIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysTeacherByUserIds(@Param("userIds") List<Long> userIds);
}
