package com.ruoyi.web.controller.columns;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.columns.SysTeacher;
import com.ruoyi.system.service.columns.ISysTeacherService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

/**
 * 教练信息Controller
 *
 * @author ruoyi
 * @date 2025-10-28
 */
@RestController
@RequestMapping("/system/teacher")
public class SysTeacherController extends BaseController
{
    @Autowired
    private ISysTeacherService sysTeacherService;


    /**
     * 查询员工信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:teacher:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysTeacher sysTeacher)
    {
        startPage();
      //  sysTeacher.setTenantId("2");
        sysTeacher.setTenantId(SecurityUtils.getLoginUser().getNowTenantId());
        List<SysTeacher> list = sysTeacherService.selectSysTeacherList(sysTeacher);
        return getDataTable(list);
    }
    /**
     * 查询员工信息列表
     */
    @GetMapping("/teacherSelect")
    public AjaxResult teacherSelect(SysTeacher sysTeacher)
    {
        sysTeacher.setTenantId(SecurityUtils.getLoginUser().getNowTenantId());
        List<SysTeacher> list = sysTeacherService.selectSysTeacherList(sysTeacher);
        return AjaxResult.successData(list);
    }

    @PreAuthorize("@ss.hasPermi('system:teacher:list')")
    @GetMapping("/getUserForTeacher")
    public AjaxResult getUserForTeacher()
    {
        SysTeacher sysTeacher=new SysTeacher();
        sysTeacher.setTenantId(SecurityUtils.getLoginUser().getNowTenantId());
        List<SysUser> list = sysTeacherService.getUserForTeacher(sysTeacher);
        return AjaxResult.successData(list);
    }


    /**
     * 导出员工信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:teacher:export')")
    @Log(title = "员工信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysTeacher sysTeacher) throws IOException {
        List<SysTeacher> list = sysTeacherService.selectSysTeacherList(sysTeacher);
        ExcelUtil<SysTeacher> util = new ExcelUtil<SysTeacher>(SysTeacher.class);
        util.exportExcel(response, list, "员工信息数据");
    }

    /**
     * 获取员工信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:teacher:query')")
    @GetMapping(value = "/{userId}")
    public AjaxResult getInfo(@PathVariable("userId") Long userId)
    {
        return AjaxResult.success(sysTeacherService.selectSysTeacherByUserId(userId));
    }

    /**
     * 新增教练信息
     */
//    @PreAuthorize("@ss.hasPermi('system:teacher:add')")
//    @Log(title = "教练信息", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody SysTeacher sysTeacher)
//    {
//        return toAjax(sysTeacherService.insertSysTeacher(sysTeacher));
//    }

    /**
     * 修改教练信息
     */
   // @PreAuthorize("@ss.hasPermi('system:teacher:edit')")
    @Log(title = "教练信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysTeacher sysTeacher)
    {
        return toAjax(sysTeacherService.updateSysTeacher(sysTeacher));
    }

//    /**
//     * 删除教练信息
//     */
//    @PostMapping("/remove")
//    public AjaxResult remove( @RequestBody List<Long> ids) {
//       return sysTeacherService.deleteSysTeacherByUserIds(ids);
//    }
}
